@@ -1,5 +1,5 @@
 package Pod::ProjectDocs::Parser;
-$Pod::ProjectDocs::Parser::VERSION = '0.42';
+$Pod::ProjectDocs::Parser::VERSION = '0.43';
 use strict;
 use warnings;
 
@@ -12,18 +12,6 @@ use Pod::ProjectDocs::Template;
 
 our $METHOD_REGEXP ||= qr/^(\w+).*/;
 
-BEGIN {
-    our $HIGHLIGHTER;
-    eval {
-        require Syntax::Highlight::Universal;
-        $HIGHLIGHTER = Syntax::Highlight::Universal->new;
-    };
-    *highlighten = $HIGHLIGHTER ? sub {
-        my ($self, $type, $str) = @_;
-        $HIGHLIGHTER->highlight($type, $str);
-    } : sub { return $_[2] };
-}
-
 # most of code is borrowed from Pod::Xhtml
 __PACKAGE__->mk_accessors(qw/components local_modules current_files_output_path/);
 __PACKAGE__->mk_classdata($_) for qw/COMMANDS SEQ language/;
@@ -617,20 +605,22 @@ sub seqX {
 sub seqE {
     my $self = shift;
     my $arg = shift;
-    my $rv;
 
     if ($arg eq 'sol') {
-        $rv = '/';
+        return '/';
     } elsif ($arg eq 'verbar') {
-        $rv = '|';
-    } elsif ($arg =~ /^\d$/) {
-        $rv = "&#$arg;";
-    } elsif ($arg =~ /^0?x(\d+)$/) {
-        $rv = $1;
-    } else {
-        $rv = "&$arg;";
+        return '|';
+    } elsif ($arg =~ /^0x([0-9a-f]+)$/i) { # hex number
+        return "&#x$1;";
+    } elsif ($arg =~ /^0[0-7]+$/) { # octal number
+        my $number = oct($arg);
+        return "&#$number;";
+    } elsif ($arg =~ /^\d+$/) { # decimal number
+        return "&#$arg;";
+    } else { # html entity
+        return "&$arg;";
     }
-    return $rv;
+    return;
 }
 
 sub gen_html {
@@ -639,7 +629,8 @@ sub gen_html {
     my $components = $args{components};
     my $mgr_desc   = $args{desc};
     delete $self->{_source_code};
-    open(FILE, $doc->origin) or warn $!;
+    my $charset = $doc->config->charset || 'UTF-8';
+    open(FILE, "<:encoding($charset)", $doc->origin) or warn $!;
     while(<FILE>) {
         next unless /^\s*sub\s+(\w+)/;
         my $method = $1;
@@ -648,14 +639,17 @@ sub gen_html {
             $sub .= $_;
             last if /^}/;
         }
-        my $result = $self->highlighten("perl", $sub);
-        $self->{_source_code}{$method} = $result;
+        $self->{_source_code}{$method} = $sub;
     }
     close(FILE);
     $self->current_files_output_path( $doc->get_output_path );
     $self->_prepare($doc, $components, $mgr_desc);
 #   local $SIG{__WARN__} = sub { };
-    $self->parse_from_file($doc->origin);
+
+    open (my $fh, "<:encoding($charset)", $doc->origin) or warn $!;
+    $self->parse_from_filehandle($fh);
+    close $fh;
+
     my $title = $self->_get_title;
     $doc->title($title);
     $self->current_files_output_path('');
